Sign Up Form - Design Connected, download 3D MODELS!
Description: 3D Models for your interior design projects / High quality 3D Models created by Designconnected - buy and save time and money

# Sign up

Login Name* |
Full Name* |
Email* |
Password* |

### Tell us more about you
Occupation |
Company |
Website |
Country |

PayLane - Verified Merchant

By signing up I agree to the EULA, Terms of Use and Privacy Policy

Model added
to shopping cart
checkout
Model removed
from shopping cart
Model added
to favorites
Model removed
from favorites
add to favoritesremove from favorites add to shopping cartremove from cart
0
Close

# You need to login first.

Log in | Sign Up | Cancel

#### Log In

Login name or email |
Password |
| Remember me

Lost password? |

Close
Access Denied

#### Compatibility

We highly recommend that you download few of our free 3d models and test if they work well with your 3d software before making a purchase.
If you have any questions about how to use Design Connected 3d models, please contact us

#### Don't miss out!

Be the first to know about our latest products, new site features and special offers.

View latest newsletter

Email |

#### Unsubscribe

Email |

#### Thank you for signing up for DesignConnected newsletter!

#### Give us your Feedback

Name |
Email |
Your comments |
| Submit

#### Designconnected rewards your loyalty!

##### Get great discounts for bulk purchases! The more models you purchase the more money you save. | ##### Every purchase you make brings you closer to additional loyal members' discounts.
For purchases from 100 to 399 you get 10% discount For purchases from 400 to 799 you get 15% discount For purchases from 800 to 1599 you get 20% discount For purchases over 1600 you get 25% discount | Members with orders of more than 300 in total get 2% discount Members with orders of more than 600 in total get 5% discount Members with orders of more than 1200 in total get 7% discount Members with orders of more than 1600 in total get 10% discount
*These bulk purchase discounts do not apply in combination with discount vouchers. | *all amounts are in Euro *discount for all future purchases

#### You didn't provide a valid VAT number!

#####

If no valid VAT number is provided, Value Added Tax at the rate for the particular country will be charged.

IMPORTANT: Design Connected will NOT issue any VAT refunds if a VAT number is provided after the purchase has already been processed.

##### Would you like to enter and validate your VAT number?

#### You didn't provide a valid VAT number!

#####

If no valid VAT number is provided, Value Added Tax at the rate for the particular country will be charged.

IMPORTANT: Design Connected will NOT issue any VAT refunds if a VAT number is provided after the purchase has already been processed.

##### Would you like to enter and validate your VAT number?